==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/ka.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ka', {
	acccessKey: 'წვდომის ღილაკი',
	advanced: 'დაწვრილებით',
	advisoryContentType: 'შიგთავსის ტიპი',
	advisoryTitle: 'სათაური',
	anchor: {
		toolbar: 'ღუზა',
		menu: 'ღუზის რედაქტირება',
		title: 'ღუზის პარამეტრები',
		name: 'ღუზუს სახელი',
		errorName: 'აკრიფეთ ღუზის სახელი',
		remove: 'Remove Anchor'
	},
	anchorId: 'ელემენტის Id-თ',
	anchorName: 'ღუზის სახელით',
	charset: 'კოდირება',
	cssClasses: 'CSS კლასი',
	emailAddress: 'ელფოსტის მისამართები',
	emailBody: 'წერილის ტექსტი',
	emailSubject: 'წერილის სათაური',
	id: 'Id',
	info: 'ბმულის ინფორმაცია',
	langCode: 'ენის კოდი',
	langDir: 'ენის მიმართულება',
	langDirLTR: 'მარცხნიდან მარჯვნივ (LTR)',
	langDirRTL: 'მარჯვნიდან მარცხნივ (RTL)',
	menu: 'ბმულის რედაქტირება',
	name: 'სახელი',
	noAnchors: '(ამ დოკუმენტში ღუზა არაა)',
	noEmail: 'აკრიფეთ ელფოსტის მისამართი',
	noUrl: 'აკრიფეთ ბმულის URL',
	other: '<სხვა>',
	popupDependent: 'დამოკიდებული (Netscape)',
	popupFeatures: 'Popup ფანჯრის პარამეტრები',
	popupFullScreen: 'მთელი ეკრანი (IE)',
	popupLeft: 'მარცხენა პოზიცია',
	popupLocationBar: 'ნავიგაციის ზოლი',
	popupMenuBar: 'მენიუს ზოლი',
	popupResizable: 'ცვალებადი ზომით',
	popupScrollBars: 'გადახვევის ზოლები',
	popupStatusBar: 'სტატუსის ზოლი',
	popupToolbar: 'ხელსაწყოთა ზოლი',
	popupTop: 'ზედა პოზიცია',
	rel: 'კავშირი',
	selectAnchor: 'აირჩიეთ ღუზა',
	styles: 'CSS სტილი',
	tabIndex: 'Tab-ის ინდექსი',
	target: 'გახსნის ადგილი',
	targetFrame: '<frame>',
	targetFrameName: 'Frame-ის სახელი',
	targetPopup: '<popup ფანჯარა>',
	targetPopupName: 'Popup ფანჯრის სახელი',
	title: 'ბმული',
	toAnchor: 'ბმული ტექსტში ღუზაზე',
	toEmail: 'ელფოსტა',
	toUrl: 'URL',
	toolbar: 'ბმული',
	type: 'ბმულის ტიპი',
	unlink: 'ბმულის მოხსნა',
	upload: 'აქაჩვა'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/ka.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ka', {
	acccessKey: 'წვდომის ღილაკი',
	advanced: 'დაწვრილებით',
	advisoryContentType: 'შიგთავსის ტიპი',
	advisoryTitle: 'სათაური',
	anchor: {
		toolbar: 'ღუზა',
		menu: 'ღუზის რედაქტირება',
		title: 'ღუზის პარამეტრები',
		name: 'ღუზუს სახელი',
		errorName: 'აკრიფეთ ღუზის სახელი',
		remove: 'Remove Anchor'
	},
	anchorId: 'ელემენტის Id-თ',
	anchorName: 'ღუზის სახელით',
	charset: 'კოდირება',
	cssClasses: 'CSS კლასი',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'ელფოსტის მისამართები',
	emailBody: 'წერილის ტექსტი',
	emailSubject: 'წერილის სათაური',
	id: 'Id',
	info: 'ბმულის ინფორმაცია',
	langCode: 'ენის კოდი',
	langDir: 'ენის მიმართულება',
	langDirLTR: 'მარცხნიდან მარჯვნივ (LTR)',
	langDirRTL: 'მარჯვნიდან მარცხნივ (RTL)',
	menu: 'ბმულის რედაქტირება',
	name: 'სახელი',
	noAnchors: '(ამ დოკუმენტში ღუზა არაა)',
	noEmail: 'აკრიფეთ ელფოსტის მისამართი',
	noUrl: 'აკრიფეთ ბმულის URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<სხვა>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'დამოკიდებული (Netscape)',
	popupFeatures: 'Popup ფანჯრის პარამეტრები',
	popupFullScreen: 'მთელი ეკრანი (IE)',
	popupLeft: 'მარცხენა პოზიცია',
	popupLocationBar: 'ნავიგაციის ზოლი',
	popupMenuBar: 'მენიუს ზოლი',
	popupResizable: 'ცვალებადი ზომით',
	popupScrollBars: 'გადახვევის ზოლები',
	popupStatusBar: 'სტატუსის ზოლი',
	popupToolbar: 'ხელსაწყოთა ზოლი',
	popupTop: 'ზედა პოზიცია',
	rel: 'კავშირი',
	selectAnchor: 'აირჩიეთ ღუზა',
	styles: 'CSS სტილი',
	tabIndex: 'Tab-ის ინდექსი',
	target: 'გახსნის ადგილი',
	targetFrame: '<frame>',
	targetFrameName: 'Frame-ის სახელი',
	targetPopup: '<popup ფანჯარა>',
	targetPopupName: 'Popup ფანჯრის სახელი',
	title: 'ბმული',
	toAnchor: 'ბმული ტექსტში ღუზაზე',
	toEmail: 'ელფოსტა',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'ბმული',
	type: 'ბმულის ტიპი',
	unlink: 'ბმულის მოხსნა',
	upload: 'აქაჩვა'
} );
